#include <WiFi.h>
#include <WiFiUdp.h>
#include <HCSR04.h>
#include <SimpleDHT.h>

#include "cave-config.h"

const char*    wifi_ssid = WIFI_SSID;
const char*    wifi_pass = WIFI_PASS;

// Grafana
IPAddress      influxdb_ip(INFLUXDB_IP);
long           influxdb_port = INFLUXDB_PORT;
unsigned int   localPort = 2390;
// MilliSeconds
long unsigned  poll_int = POLL_INT;
String city = CITY;
String location = LOCATION;
WiFiUDP Udp;

// TRIGGER, ECHO
UltraSonicDistanceSensor distanceSensor(14, 12);

// Temp
int pinDHT22 = 27;
SimpleDHT22 dht22(pinDHT22);

void setup() {

  #if defined(DEBUG)
  Serial.begin(115200);
  Serial.print("Connecting to ");
  Serial.println(wifi_ssid);
  #endif

  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);

  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    #if defined(DEBUG)
    Serial.print(".");
    #endif
  }

  #if defined(DEBUG)
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
  #endif
}

void loop() {
  float temperature = 0;
  float humidity = 0;
  int err = SimpleDHTErrSuccess;
  if ((err = dht22.read2(&temperature, &humidity, NULL)) == SimpleDHTErrSuccess) {
    sendToInfluxDB("temperature,city="+city+",location="+location, "value", String(temperature));
    sendToInfluxDB("humidity,city="+city+",location="+location, "value", String(humidity));
  }
  double water_dist = distanceSensor.measureDistanceCm(temperature);
  #if defined(DEBUG)
  Serial.println("Distance: "+String(water_dist));
  #endif
  sendToInfluxDB("water_well,city="+city+",location="+location, "distance", String(water_dist));
  delay(POLL_INT); 
}

void sendToInfluxDB(String measure, String key, String value) {
  String line = measure+" "+key+"="+value;
  Udp.begin(localPort);
  Udp.beginPacket(influxdb_ip, influxdb_port);
  Udp.print(line);
  Udp.endPacket();
}
